#!/usr/bin/perl
#############################################################################
# Example CGI usage of TiVo.pm
# Version 1.1
# 3/17/2003
#
# Copyright (c) 2003 TiVo Inc. All Rights Reserved.
#
# This file contains Original Code and/or Modifications of Original Code
# as defined in and that are subject to the TiVo Public Source License
# Version 1.0 (the 'License'). You may not use this file except in
# compliance with the License. Please obtain a copy of the License at
# http://www.tivo.com/developer/tivo_license.asp and read it before
# using this file.
#
# THE ORIGINAL CODE AND ALL SOFTWARE DISTRIBUTED UNDER THE LICENSE ARE
# PROVIDED _AS IS_, WITH ALL FAULTS AND WITHOUT WARRANTY OF ANY KIND,
# EITHER EXPRESS OR IMPLIED.  TIVO HEREBY DISCLAIMS ALL SUCH WARRANTIES
# INCLUDING, BUT NOT LIMITED TO,  WARRANTIES AND/OR CONDITIONS OF FITNESS
# FOR A PARTICULAR PURPOSE, MERCHANTABILITY, AND NON-INFRINGEMENT OF THIRD
# PARTY RIGHTS, EXCLUSIVELY OR RESULTS OBTAINED FROM USE OF THE MATERIAL.
# TIVO MAKES NO WARRANTY OF ANY KIND WITH RESPECT TO FREEDOM FROM PATENT,
# TRADEMARK, OR COPYRIGHT INFRINGEMENT.  Please see the License for
# specific language governing rights and limitations under the License.
#
#############################################################################

##
## Install this CGI using the following Apache directive:
##   Alias /TiVoConnect /FULL/path/to/TiVoConnect.cgi
##
## Be sure to enable the CGI handler for .cgi extensions
##

use TiVo;

## Create a Server identified as "My Server" which
## uses /tmp to store cache data.

my $server = TiVo::Server->new(
  SERVER_NAME => "My Server",
  CACHE_DIR => "/tmp"
);

## Create a Music service using files found under
## "/home/tivo/music", mapped to the virtual path "/Music",
## and using the default service name.

my $music_service = TiVo::Container::Music->new(
  PATH => "/home/tivo/Music",
  SERVICE => "/Music"
);
$server->add_service( $music_service );

## Create a Photo service using files found under
## "/home/tivo/photos", mapped to the virtual path "/Photos",
## and using a service name of "My Personal Photos".

my $photo_service = TiVo::Container::Photos->new(
  PATH => "/home/tivo/Photos",
  SERVICE => "/Photos",
  TITLE => "My Personal Photos"
);
$server->add_service( $photo_service );

## Process a request using environment variables set by
## web server

my( $headers, $data ) = $server->request(
  $ENV{'SCRIPT_NAME'},
  $ENV{'PATH_INFO'},
  $ENV{'QUERY_STRING'}
);

# Command failed completely if no headers were returned
if( defined($headers) ) {

  # Print the recommended headers
  foreach ( keys %$headers ) {
    print "$_: ", $headers->{$_}, "\r\n" if $headers->{$_};
  }
  print "\r\n";

  # If the returned data is a scalar ref, simply print it out
  if( ref $data eq 'SCALAR' ) {

    print $$data;

  # If it's a filehandle ref, read from the file
  } elsif( ref $data eq 'IO::File' ) {

    my $block;
    while( $data->read($block, 1024) ) {
      print $block;
    }

    # Close file
    undef $data;

  }

} else {

  print "Status: 404 Not Found\r\n";
  print "\r\n";
  print "Bad request.\n";

}

exit;
